@@ -79,7 +79,11 @@ Version 1.5
 Version 1.6
 - minor bug fix in conversion_float.py
 - add licence text
+Version 1.7
 - fix bug in thread-safe version
+Version 1.8
+- bug in select_for_update if used with a list of fields instead of None
+- bug in __init__.py
 """
 
 import os
@@ -106,7 +110,7 @@ from buzhug_files import *
 import buzhug_algos
 import buzhug_info
 
-version = "1.6"
+version = "1.8"
 
 # ------------------------
 # The following classes are used to modelize the objects in the
@@ -888,31 +892,36 @@ class Base:
                 ix = self.field_names.index(k)
                 self._file[k].write_value_at_pos(field_pos[ix],v)
         else:
-            # mark row in field files as deleted
-            for dp,f in zip(field_pos,self.field_names):
-                self._file[f].mark_as_deleted(dp)
-            # add a deleted row
-            self._del_rows.insert(field_pos[0]/5)
+            # the record to update may not have all the database fields
+            # for missing fields, just write a copy at the end of field file
             new_pos = {}
-            # copy blocks at the end of field files for fields not updated
-            unset_fields = [ (i,f) for (i,f) in enumerate(self.field_names)
+            missing_fields = [ (i,f) for (i,f) in enumerate(self.field_names)
                 if not hasattr(record,f) ]
-            for i,f in unset_fields:
+            for i,f in missing_fields:
                 pos = field_pos[i]
                 block = self._file[f].get_block_at_pos(pos)
                 new_pos[f] = self._file[f].get_end_pos()
                 self._file[f].write(block)
                 self._file[f].seek(0,2)
+
+            # record fields
             set_fields = [ f for f in self.field_names if hasattr(record,f) ]
-            #r_dict = dict([(f,getattr(record,k)) for f in set_fields ])
             # write new values in field files
             for f in set_fields:
                 new_pos[f] = self._file[f].get_end_pos()
                 self._file[f].insert(getattr(record,f))
+
+            # update positions in the position file
             pos = [ new_pos[f] for f in self.field_names ]
-            # override line in position file
             self._pos.update(_line_in_pos,pos)
 
+            # for previous version of the record, 
+            # mark row in field files as deleted
+            for dp,f in zip(field_pos,self.field_names):
+                self._file[f].mark_as_deleted(dp)
+            # add a deleted row
+            self._del_rows.insert(field_pos[0]/5)
+
     def add_field(self,field_name,field_type,after=None,default=None):
         """Add a new field after the specified field, or in the beginning if
         no field is specified"""
