@@ -202,7 +202,7 @@ class UnicodeFile(StringFile):
         if block == '!\n':
             return None
         else:
-            return StringFile.from_block(self,block.decode('utf-8'))
+            return StringFile.from_block(self,block).decode('utf-8')
 
 
 # Generic class for dates
